==> qtjambi-qt3dcore-5.15.3-sources.jar: io/qt/qt3d/core/QNodeId.java <==
package io.qt.qt3d.core;


/**
 * <p>Uniquely identifies a QNode</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3dcore-qnodeid.html">Qt3DCore::QNodeId</a></p>
 */
public class QNodeId extends io.qt.QtObject
    implements java.lang.Comparable<io.qt.qt3d.core.QNodeId>,
            java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public QNodeId(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNodeId instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodeid.html#id">Qt3DCore::QNodeId::id()const</a></p>
     */
    @io.qt.QtUninvokable
    public final long id(){
        return id_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native long id_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodeid.html#isNull">Qt3DCore::QNodeId::isNull()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isNull(){
        return isNull_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isNull_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodeid.html#operator-lt">Qt3DCore::QNodeId::operator&lt;(Qt3DCore::QNodeId)const</a></p>
     */
    @io.qt.QtUninvokable
    private final boolean operator_less(io.qt.qt3d.core.QNodeId other){
        return operator_less_native_Qt3DCore_QNodeId_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native boolean operator_less_native_Qt3DCore_QNodeId_constfct(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodeid.html#operator-eq-eq">Qt3DCore::QNodeId::operator==(Qt3DCore::QNodeId)const</a></p>
     */
    @io.qt.QtUninvokable
    private final boolean operator_equal(io.qt.qt3d.core.QNodeId other){
        return operator_equal_native_Qt3DCore_QNodeId_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native boolean operator_equal_native_Qt3DCore_QNodeId_constfct(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodeid.html#createId">Qt3DCore::QNodeId::createId()</a></p>
     */
    public native static io.qt.qt3d.core.QNodeId createId();
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNodeId(QPrivateConstructor p) { super(p); } 
    

    @Override
    @io.qt.QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.qt3d.core.QNodeId) {
            return operator_equal((io.qt.qt3d.core.QNodeId) other);
        }

        return false;
    }

    @io.qt.QtUninvokable
    public int compareTo(io.qt.qt3d.core.QNodeId other) {
        if (equals(other)) return 0;
        else if (operator_less(other)) return -1;
        else return 1;
    }


    @io.qt.QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private native static int hashCode_native(long __this_nativeId);

    @Override
    @io.qt.QtUninvokable
    public String toString() {
        return toString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private static native String toString_native(long __this_nativeId);
    
    @Override
    public QNodeId clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QNodeId clone_native(long __this_nativeId);
}

==> qtjambi-qt3dcore-5.15.13-sources.jar: io/qt/qt3d/core/QNodeId.java <==
package io.qt.qt3d.core;


/**
 * <p>Uniquely identifies a QNode</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qnodeid.html">Qt3DCore::QNodeId</a></p>
 */
public class QNodeId extends io.qt.QtObject
    implements java.lang.Comparable<io.qt.qt3d.core.QNodeId>,
            java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public QNodeId(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNodeId instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodeid.html#id">Qt3DCore::QNodeId::id()const</a></p>
     */
    @io.qt.QtUninvokable
    public final long id(){
        return id_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native long id_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodeid.html#isNull">Qt3DCore::QNodeId::isNull()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isNull(){
        return isNull_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isNull_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodeid.html#operator-lt">Qt3DCore::QNodeId::operator&lt;(Qt3DCore::QNodeId)const</a></p>
     */
    @io.qt.QtUninvokable
    private final boolean operator_less(io.qt.qt3d.core.QNodeId other){
        return operator_less_native_Qt3DCore_QNodeId_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native boolean operator_less_native_Qt3DCore_QNodeId_constfct(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodeid.html#operator-eq-eq">Qt3DCore::QNodeId::operator==(Qt3DCore::QNodeId)const</a></p>
     */
    @io.qt.QtUninvokable
    private final boolean operator_equal(io.qt.qt3d.core.QNodeId other){
        return operator_equal_native_Qt3DCore_QNodeId_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native boolean operator_equal_native_Qt3DCore_QNodeId_constfct(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodeid.html#createId">Qt3DCore::QNodeId::createId()</a></p>
     */
    public native static io.qt.qt3d.core.QNodeId createId();
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNodeId(QPrivateConstructor p) { super(p); } 
    

    @Override
    @io.qt.QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.qt3d.core.QNodeId) {
            return operator_equal((io.qt.qt3d.core.QNodeId) other);
        }

        return false;
    }

    @io.qt.QtUninvokable
    public int compareTo(io.qt.qt3d.core.QNodeId other) {
        if (equals(other)) return 0;
        else if (operator_less(other)) return -1;
        else return 1;
    }


    @io.qt.QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private native static int hashCode_native(long __this_nativeId);

    @Override
    @io.qt.QtUninvokable
    public String toString() {
        return toString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private static native String toString_native(long __this_nativeId);
    
    @Override
    public QNodeId clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QNodeId clone_native(long __this_nativeId);
}
